@@ -28,7 +28,7 @@ from kodexa.connectors import get_source
 from kodexa.connectors.connectors import get_caller_dir, FolderConnector
 from kodexa.model import Document, ExtensionPack
 from kodexa.model.objects import AssistantDefinition, Action, Taxonomy, ModelRuntime, Credential, ExecutionEvent, \
-    ContentObject
+    ContentObject, ModelTrainEvent, AssistantEvent, ContentEvent, ScheduledEvent
 from kodexa.pipeline import PipelineContext, Pipeline, PipelineStatistics
 from kodexa.stores import RemoteDocumentStore, RemoteDataStore
 from kodexa.stores import TableDataStore, RemoteModelStore, LocalDocumentStore, LocalModelStore
@@ -225,7 +225,7 @@ def resolve_object_type(obj_type):
         return keys[0], hits[0]
 
     if len(hits) == 0:
-        print(":exclaimation: Unable to find object type {obj_type}")
+        print(f":exclaimation: Unable to find object type {obj_type}")
         sys.exit(1)
     else:
         print(f":exclaimation: To many potential matches for object type ({','.join(keys)}")
@@ -414,17 +414,18 @@ class KodexaPlatform:
     def get_object_instance(ref: str, object_type):
         object_type, object_type_metadata = resolve_object_type(object_type)
 
-        if object_type_metadata.type is Taxonomy:
-            KodexaPlatform.__build_object(ref, object_type_metadata, Taxonomy)
+        if object_type_metadata['type'] is Taxonomy:
+            return KodexaPlatform.__build_object(ref, object_type_metadata, Taxonomy)
+
         if object_type == 'stores':
             # We need to work out what type of store we have
             obj_info = KodexaPlatform.get_object(ref, object_type)
             if obj_info['storeType'] == 'TABLE':
                 return KodexaPlatform.__build_object(ref, object_type_metadata, RemoteDataStore)
             if obj_info['storeType'] == 'DOCUMENT':
-                KodexaPlatform.__build_object(ref, object_type_metadata, RemoteDocumentStore)
+                return KodexaPlatform.__build_object(ref, object_type_metadata, RemoteDocumentStore)
             if obj_info['storeType'] == 'MODEL':
-                KodexaPlatform.__build_object(ref, object_type_metadata, RemoteModelStore)
+                return KodexaPlatform.__build_object(ref, object_type_metadata, RemoteModelStore)
 
         # TODO - there are other things we need?
         raise Exception(f"Unable to get a local instance of {ref} of type {object_type}")
@@ -1127,6 +1128,19 @@ class EventHelper:
     def __init__(self, event: ExecutionEvent):
         self.event: ExecutionEvent = event
 
+    @staticmethod
+    def get_base_event(event_dict: Dict):
+        if event_dict['type'] == 'modelTrain':
+            return ModelTrainEvent(**event_dict)
+        if event_dict['type'] == 'assistant':
+            return AssistantEvent(**event_dict)
+        if event_dict['type'] == 'content':
+            return ContentEvent(**event_dict)
+        if event_dict['type'] == 'scheduled':
+            return ScheduledEvent(**event_dict)
+
+        raise f"Unknown event type {event_dict}"
+
     def log(self, message: str):
         requests.post(
             f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution_id}/log",
@@ -1152,7 +1166,7 @@ class EventHelper:
             "content": content
         }
         data = {
-            "contentObjectJson": json.dumps(content_object.dict())
+            "contentObjectJson": json.dumps(content_object.dict(by_alias=True))
         }
         logger.info("Posting back content object to execution object")
         co_response = requests.post(
